@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: action.py 745 2005-04-01 23:25:47Z pronovic $
+# Revision : $Id: action.py 755 2005-04-23 17:48:47Z pronovic $
 # Purpose  : Provides implementation of various backup-related actions.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -700,7 +700,7 @@ def _writeCollectIndicator(config):
       open(filename, "w").write("")
       changeOwnership(filename, config.options.backupUser, config.options.backupGroup)
    except Exception, e:
-      logger.error("Error writing collect indicator: %s", e)
+      logger.error("Error writing collect indicator: %s" % e)
 
 
 ##########################
@@ -817,7 +817,7 @@ def _writeStageIndicator(config, dailyDir):
       open(filename, "w").write("")
       changeOwnership(filename, config.options.backupUser, config.options.backupGroup)
    except Exception, e:
-      logger.error("Error writing stage indicator: %s", e)
+      logger.error("Error writing stage indicator: %s" % e)
 
 
 ##########################
@@ -1014,7 +1014,7 @@ def _writeStoreIndicator(config, stagingDirs):
          open(filename, "w").write("")
          changeOwnership(filename, config.options.backupUser, config.options.backupGroup)
       except Exception, e:
-         logger.error("Error writing store indicator: %s", e)
+         logger.error("Error writing store indicator: %s" % e)
 
 
 ##########################
