@@ -11,6 +11,9 @@
 # Copyright (c) 2004-2005 Kenneth J. Pronovici.
 # All rights reserved.
 #
+# Portions copyright (c) 2001, 2002 Python Software Foundation.
+# All Rights Reserved.
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License,
 # Version 2, as published by the Free Software Foundation.
@@ -27,7 +30,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: util.py 690 2005-03-10 03:35:28Z pronovic $
+# Revision : $Id: util.py 751 2005-04-18 21:54:31Z pronovic $
 # Purpose  : Provides general-purpose utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -112,6 +115,9 @@ UNIT_SECTORS       = 3
 MTAB_FILE          = "/etc/mtab"
 DEV_NULL_PATH      = "/dev/null"
 
+MOUNT_CMD          = [ "mount", ]
+UMOUNT_CMD         = [ "umount", ]
+
 
 ########################################################################
 # UnorderedList class definition
@@ -426,6 +432,10 @@ class Pipe(popen2.Popen4):
    constructor and then modify a few things afterwards.  Even worse, I have to
    access private C{popen2} module members C{_cleanup} and C{_active} in order
    to duplicate the implementation.  Hopefully that will continue to work. :(
+   
+   @copyright: Some of this code, prior to customization, was originally part
+   of the Python 2.3 codebase.  Python code is copyright (c) 2001, 2002 Python
+   Software Foundation; All Rights Reserved.
    """
    
    def __init__(self, cmd, bufsize=-1, ignoreStderr=False):
@@ -587,6 +597,10 @@ def getFunctionReference(module, function):
 
    @raise ImportError: If the function cannot be found. 
    @raise ValueError: If the resulting reference is not callable.
+
+   @copyright: Some of this code, prior to customization, was originally part
+   of the Python 2.3 codebase.  Python code is copyright (c) 2001, 2002 Python
+   Software Foundation; All Rights Reserved.
    """
    parts = []
    if module is not None and module != "":
@@ -809,6 +823,90 @@ def calculateFileAge(file):
    return ageInDays
 
 
+###################
+# mount() function
+###################
+
+def mount(devicePath, mountPoint, fsType):
+   """
+   Mounts the indicated device at the indicated mount point.
+
+   For instance, to mount a CD, you might use device path C{/dev/cdrw}, mount
+   point C{/media/cdrw} and filesystem type C{iso9660}.  You can safely use any
+   filesystem type that is supported by C{mount} on your platform.  If the type
+   is C{None}, we'll attempt to let C{mount} auto-detect it.  This may or may
+   not work on all systems.
+
+   @param devicePath: Path of device to be mounted.
+   @param mountPoint: Path that device should be mounted at.
+   @param fsType: Type of the filesystem assumed to be available via the device.
+
+   @raise IOError: If the device cannot be mounted.
+   """
+   if fsType is None:
+      args = [ devicePath, mountPoint ]
+   else:
+      args = [ "-t", fsType, devicePath, mountPoint ]
+   result = executeCommand(MOUNT_CMD, args, returnOutput=False, ignoreStderr=True)[0]
+   if result != 0:
+      raise IOError("Error [%d] mounting [%s] at [%s] as [%s]." % (result, devicePath, mountPoint, fsType))
+
+
+#####################
+# unmount() function
+#####################
+
+def unmount(mountPoint, removeAfter=False, attempts=1, waitSeconds=0):
+   """
+   Unmounts whatever device is mounted at the indicated mount point.
+
+   Sometimes, it might not be possible to unmount the mount point immediately,
+   if there are still files open there.  Use the C{attempts} and C{waitSeconds}
+   arguments to indicate how many unmount attempts to make and how many seconds
+   to wait between attempts.  If you pass in zero attempts, no attempts will be
+   made (duh).
+
+   If the indicated mount point is not really a mount point per
+   C{os.path.ismount()}, then it will be ignored.  This seems to be a safer
+   check then looking through C{/etc/mtab}, since C{ismount()} is already in
+   the Python standard library and is documented as working on all POSIX
+   systems.
+
+   If C{removeAfter} is C{True}, then the mount point will be removed using
+   C{os.rmdir()} after the unmount action succeeds.  If for some reason the
+   mount point is not a directory, then it will not be removed.
+
+   @param mountPoint: Mount point to be unmounted.
+   @param removeAfter: Remove the mount point after unmounting it.
+   @param attempts: Number of times to attempt the unmount.
+   @param waitSeconds: Number of seconds to wait between repeated attempts.
+
+   @raise IOError: If the mount point is still mounted after attempts are exhausted.
+   """
+   if os.path.ismount(mountPoint):
+      for attempt in range(0, attempts):
+         logger.debug("Making attempt %d to unmount [%s]." % (attempt, mountPoint))
+         result = executeCommand(UMOUNT_CMD, [ mountPoint, ], returnOutput=False, ignoreStderr=True)[0]
+         if result != 0:
+            logger.error("Error [%d] unmounting [%s] on attempt %d." % (result, mountPoint, attempt))
+         elif os.path.ismount(mountPoint):
+            logger.error("After attempt %d, [%s] is still mounted." % (attempt, mountPoint))
+         else:
+            logger.debug("Successfully unmounted [%s] on attempt %d." % (mountPoint, attempt))
+            break  # this will cause us to skip the loop else: clause
+         if attempt+1 < attempts:  # i.e. this isn't the last attempt
+            if waitSeconds > 0:
+               logger.info("Sleeping %d second(s) before next unmount attempt." % waitSeconds)
+               time.sleep(waitSeconds)
+      else:
+         if os.path.ismount(mountPoint):
+            raise IOError("Unable to unmount [%s] after %d attempts." % (mountPoint, attempts))
+         logger.info("Mount point [%s] seems to have finally gone away." % mountPoint)
+      if os.path.isdir(mountPoint) and removeAfter:
+         logger.debug("Removing mount point [%s]." % mountPoint)
+         os.rmdir(mountPoint)
+
+
 ###########################
 # deviceMounted() function
 ###########################
