@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: writer.py 752 2005-04-22 15:23:54Z pronovic $
+# Revision : $Id: writer.py 755 2005-04-23 17:48:47Z pronovic $
 # Purpose  : Provides image writer-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -618,7 +618,10 @@ class CdWriter(object):
          if result != 0:
             raise IOError("Error (%d) executing cdrecord command to get capacity." % result)
          boundaries = CdWriter._parseBoundariesOutput(output)
-         logger.debug("Returning disc boundaries:", boundaries)
+         if boundaries is None:
+            logger.debug("Returning disc boundaries: None")
+         else:
+            logger.debug("Returning disc boundaries: (%d, %d)" % (boundaries[0], boundaries[1]))
          return boundaries
 
    def _calculateCapacity(media, boundaries):
